==> sdk-1.0.0-sources.jar: com/example/sdk/GT3GeetestBean.java <==
package com.example.sdk;

/**
 * 项目中要请求得到的bean
 */
public class GT3GeetestBean {
    private String gt;
    private String gtt;
    private String challenge;
    private int success;
    private String api_server;
    private String result;
    private String theme;
    private String static_servers;
    private String static_servers2;
    private  String click;
    private  String slide;
    private String downtimechallenge;
    private String validate;
    private boolean logo;
    public GT3GeetestBean() {

    }

    public String getGtt() {
        return gtt;
    }

    public void setGtt(String gtt) {
        this.gtt = gtt;
    }

    public String getSlide() {
        return slide;
    }

    public void setSlide(String slide) {
        this.slide = slide;
    }

    public String getValidate() {
        return validate;
    }

    public void setValidate(String validate) {
        this.validate = validate;
    }

    public boolean isLogo() {
        return logo;
    }

    public void setLogo(boolean logo) {
        this.logo = logo;
    }

    public String getDowntimechallenge() {
        return downtimechallenge;
    }

    public void setDowntimechallenge(String downtimechallenge) {
        this.downtimechallenge = downtimechallenge;
    }

    public String getClick() {
        return click;
    }

    public void setClick(String click) {
        this.click = click;
    }

    public String getStatic_servers2() {
        return static_servers2;
    }

    public void setStatic_servers2(String static_servers2) {
        this.static_servers2 = static_servers2;
    }

    public String getStatic_servers() {
        return static_servers;
    }

    public void setStatic_servers(String static_servers) {
        this.static_servers = static_servers;
    }

    public String getGt() {
        return gt;
    }

    public void setGt(String gt) {
        this.gt = gt;
    }

    public String getChallenge() {
        return challenge;
    }

    public void setChallenge(String challenge) {
        this.challenge = challenge;
    }

    public int getSuccess() {
        return success;
    }

    public void setSuccess(int success) {
        this.success = success;
    }

    public String getApi_server() {
        return api_server;
    }

    public void setApi_server(String api_server) {
        this.api_server = api_server;
    }

    public String getResult() {
        return result;
    }

    public void setResult(String result) {
        this.result = result;
    }

    public String getTheme() {
        return theme;
    }

    public void setTheme(String theme) {
        this.theme = theme;
    }


}

==> sdk-1.1.0-sources.jar: com/example/sdk/GT3GeetestBean.java <==
package com.example.sdk;

/**
 * 项目中要请求得到的bean
 */
public class GT3GeetestBean {
    private String gt;
    private String gt2;
    private String challenge;
    private String challenge2;
    private int success;
    private int success2;
    private String api_server;
    private String result;
    private String theme;
    private String static_servers;
    private String static_servers2;
    private  String click;
    private  String slide;
   private String validate;
    private boolean logo;
    public GT3GeetestBean() {

    }

    public int getSuccess2() {
        return success2;
    }

    public void setSuccess2(int success2) {
        this.success2 = success2;
    }

    public String getGt2() {
        return gt2;
    }

    public void setGt2(String gt2) {
        this.gt2 = gt2;
    }

    public String getChallenge2() {
        return challenge2;
    }

    public void setChallenge2(String challenge2) {
        this.challenge2 = challenge2;
    }

    public String getSlide() {
        return slide;
    }

    public void setSlide(String slide) {
        this.slide = slide;
    }

    public String getValidate() {
        return validate;
    }

    public void setValidate(String validate) {
        this.validate = validate;
    }

    public boolean isLogo() {
        return logo;
    }

    public void setLogo(boolean logo) {
        this.logo = logo;
    }

    public String getClick() {
        return click;
    }

    public void setClick(String click) {
        this.click = click;
    }

    public String getStatic_servers2() {
        return static_servers2;
    }

    public void setStatic_servers2(String static_servers2) {
        this.static_servers2 = static_servers2;
    }

    public String getStatic_servers() {
        return static_servers;
    }

    public void setStatic_servers(String static_servers) {
        this.static_servers = static_servers;
    }

    public String getGt() {
        return gt;
    }

    public void setGt(String gt) {
        this.gt = gt;
    }

    public String getChallenge() {
        return challenge;
    }

    public void setChallenge(String challenge) {
        this.challenge = challenge;
    }

    public int getSuccess() {
        return success;
    }

    public void setSuccess(int success) {
        this.success = success;
    }

    public String getApi_server() {
        return api_server;
    }

    public void setApi_server(String api_server) {
        this.api_server = api_server;
    }

    public String getResult() {
        return result;
    }

    public void setResult(String result) {
        this.result = result;
    }

    public String getTheme() {
        return theme;
    }

    public void setTheme(String theme) {
        this.theme = theme;
    }


}
